@@ -1,8 +1,8 @@
-from scTenifold.core import *
+from .core import *
 
 
 __all__ = ['scTenifoldNet', 'scTenifoldKnk',
            "sc_QC", "make_networks", "manifold_alignment", "d_regulation"]
 
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
